@@ -7,7 +7,9 @@
 #' @references Snijders, T. A. B., & Bosker, R. J. (1999). Multilevel Analysis. Sage Publications.
 #' @seealso anova.lsasimcluster
 calc_var_between <- function(n_j, y_bar_j, y_bar, n_tilde, N) {
-    if (class(y_bar_j)[1] != "matrix") y_bar_j <- as.matrix(y_bar_j)
+    if (!is(y_bar_j[1], "matrix")) {
+        y_bar_j <- as.matrix(y_bar_j)
+    }
     if (is.null(colnames(y_bar_j))) {
         X <- ncol(y_bar_j)
     } else {
@@ -22,4 +24,4 @@ calc_var_between <- function(n_j, y_bar_j, y_bar, n_tilde, N) {
     }
     names(s2_between) <- X
     return(s2_between)
-}
\ No newline at end of file
+}
